# vsmodupdater

A tool for updating VintageStory mods.

## Installing

- run `pipx install vsmodupdater`

## Usage

- run `vsmodupdater` to update mods
- run `vsmodupdater -i modid1 modid2` or `vsmodupdater -I mods.txt` to install mods
- run `vsmodupdater -r modid1 modid2` or `vsmodupdater -R mods.txt` to remove mods
- run `vsmodupdater -D -` or `vsmodupdater -D mods.txt` to dump installed mods
- for help run `vsmodupdater --help`
